@@ -10,11 +10,12 @@ from django.template.loader import render_to_string
 from django.utils.translation import ugettext_lazy as _
 from django.db import models
 
-from django_nopassword.utils import User, get_username
+from django_nopassword.utils import get_username, AUTH_USER_MODEL
 
 
 class LoginCode(models.Model):
-    user = models.ForeignKey(User, related_name='login_codes', editable=False, verbose_name=_('user'))
+    user = models.ForeignKey(AUTH_USER_MODEL, related_name='login_codes',
+                             editable=False, verbose_name=_('user'))
     code = models.CharField(max_length=20, editable=False, verbose_name=_('code'))
     timestamp = models.DateTimeField(editable=False)
     next = models.TextField(editable=False, blank=True)
@@ -68,5 +69,5 @@ class LoginCode(models.Model):
 
     @classmethod
     def generate_code(cls, length=20):
-        chars = string.letters + string.digits
-        return ''.join([choice(chars) for i in xrange(length)])
+        chars = string.ascii_letters + string.digits
+        return ''.join([choice(chars) for i in range(length)])
