@@ -1,19 +1,30 @@
 # -*- coding: utf8 -*-
 
 DEBUG = False
-
-DATABASES = {
-    'default': {
-        'ENGINE': 'django.db.backends.postgresql_psycopg2',
-        'NAME': 'django_nopassword',
-    }
-}
+USE_SQLITE = True
 
 try:
     from local import *
 except ImportError:
     pass
 
+if USE_SQLITE:
+    DATABASES = {
+        'default': {
+            'ENGINE': 'django.db.backends.sqlite3',
+            'NAME': ':memory:',
+        }
+    }
+
+else:
+    DATABASES = {
+        'default': {
+            'ENGINE': 'django.db.backends.postgresql_psycopg2',
+            'NAME': 'django_nopassword',
+        }
+    }
+
+
 AUTH_USER_MODEL = 'tests.CustomUser'
 
 NOPASSWORD_LOGIN_CODE_TIMEOUT = 900
